/*
 *  file      : src/dragNdrop.c
 *  project   : b2im
 *  copyright : (C) 2015 by BULIN Claude
 * 
 *  This file is part of b2im project
 * 
 *  b2im is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; version 3.
 * 
 *  b2im is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 * 
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 *  USA
 */




#ifdef HAVE_CONFIG_H
	#include "../config.h"
#endif

#include <gtk/gtk.h>
#include <glib/gprintf.h>
#include <string.h>

#ifdef ENABLE_STATIC_LIBRARY
	#include "../lib_b2im/lib.h"
#endif

#include "global.h"
#include "dragNdrop.h"



/*
*---------------------------------------------------------------------------
* VARIABLES
*---------------------------------------------------------------------------
*/


enum {
        TARGET_STRING = 0,
        TARGET_URL,
        TARGET_ROOTWIN
};

const GtkTargetEntry drag_types[] = {
	{ "STRING",        0, TARGET_STRING },
	{ "text/uri-list", 0, TARGET_URL }

};

gint n_drag_types = G_N_ELEMENTS (drag_types);

gchar *dragndrop_xcfa_convert_utf8 (gchar *Texte);


/*
*---------------------------------------------------------------------------
* FUNCTIONS
*---------------------------------------------------------------------------
*/

/* Cette fonction est appelle depuis 'file.c :: file_drag_data_received_file' et elle
*  extrait les noms de fichiers pour les injecter dans le 'GList EnteteFile.GList_file'
*  --
*  entree :
*      GtkWidget *widget : L'adresse du widget destinataire
*      gchar *string     : pointeur buffer de texte
*  retour : -
*/
void dragndrop_list_drag_data( GtkWidget *widget, gchar *string )
{
	gboolean	Bool_add_ok = FALSE;
	gchar		*Src = NULL;
	gchar		*Ptr = NULL;
	gchar		*temp = NULL;
	GSList		*List = NULL;
	GSList		*gs_List = NULL;
	
	// ALLOC CHAINE
	Src = dragndrop_xcfa_convert_utf8 (string);
	
	// POINTEUR SUR LA CHAINE TRADUITE
	Ptr = Src;
	while (*Ptr)
	{
		if (NULL != (temp = strchr (Ptr, '\n'))) {
			if (*(temp - 1) == '\r') *(temp - 1) = '\0';
			*temp = '\0';
		}
		List = g_slist_append (List, Ptr);
		Bool_add_ok = TRUE;
		if (NULL == temp) break;

		Ptr = temp + 1;
	}
	
	if (TRUE == Bool_add_ok) {
		if( widget == GTK_WIDGET(GLADE_GET_OBJECT("drawingarea_img_boot")) )
			NtbGfxBoot_add_img_file_to_Drawingarea( List );
		
		else if( widget == GTK_WIDGET(GLADE_GET_OBJECT("textview_add_to_home")) ||
				 widget == GTK_WIDGET(GLADE_GET_OBJECT("textview_add_to_home_config")) ||
				 widget == GTK_WIDGET(GLADE_GET_OBJECT("textview_add_to_home_local_share")) )
			NtbHome_add_datas_to_( widget, List );
		
		gs_List = List;
		while( gs_List ) {
			gs_List->data = NULL;
			gs_List = g_slist_next( gs_List );
		}
		g_slist_free( List );
		List = NULL;
	}

	// LIBERATION CHAINE
	g_free( Src );
	Src = Ptr = NULL;
}

/* Lors d'un drag and drop, les caracteres sont curieusements transformés en CAR utf-8,
*  par exemple : c8 apparait comme 'C' et '8' dans le texte, il faut alors le chercher et
*  le retransformer en numerique decimale puis le reinjecter dans le buffer
*  --
*  entree :
*      gchar *Texte : pointeur buffer de texte
*  retour : -
*      gchar * : pointeur nouveau buffer de texte
*/
gchar *dragndrop_xcfa_convert_utf8( gchar *Text )
{
	gchar    *Ptr = NULL;
	gchar    *New_Str = NULL;
	gchar    *Ptr_Txt = NULL;
	gchar     Str [ 8 ];
	size_t    Len;
	
	/* allocate new string
	*/
	Len = strlen( Text );

	New_Str = g_strnfill( Len * 3, '\0' );
	Ptr = New_Str;

	/* delette this 'file://' in old string
	*/
	while( NULL != (Ptr_Txt = strstr( Text, "file://" ))) {
		strcpy( Ptr_Txt, Ptr_Txt + 7 );
	}
	Ptr_Txt = Text;

	Str [ 0 ] = '0';
	Str [ 1 ] = 'x';
	Str [ 2 ] = '\0';
	Str [ 3 ] = '\0';
	Str [ 4 ] = '\0';
	Str [ 5 ] = '\0';

	while( *Ptr_Txt ) {
		if( *Ptr_Txt == '%' ) {
			Ptr_Txt ++;
			Str [ 2 ] = *Ptr_Txt ++;
			Str [ 3 ] = *Ptr_Txt ++;
			*Ptr = (gint)libutils_hexa_to_int( Str );
			Ptr ++;
		}
		else {
			*Ptr ++ = *Ptr_Txt ++;
		}
	}

	return( New_Str );
}



